@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use experimental qw( signatures declared_refs refaliasing );
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Iterator::Flex::Utils qw( RETURN STATE EXHAUSTION :IterAttrs :IterStates );
 use Iterator::Flex::Factory;
@@ -66,20 +66,22 @@ sub new ( $class, @args ) {
 }
 
 sub construct ( $class, $state ) {
-    $class->_throw( parameter => "state must be a HASH reference" )
+    $class->_throw( parameter => q{state must be a HASH reference} )
       unless Ref::Util::is_hashref( $state );
 
     $state->{value} //= [];
 
-    my ( \@depends, $current_iterator_index, $prev, $current, $next, $thaw )
+    my ( \@depends, $current_iterator_index, $prev, $current, $next, undef )
       = @{$state}{ 'depends', 'current_iterator_index', 'prev', 'current', 'next', 'thaw' };
 
     # transform into iterators if required.
     my @iterators
-      = map { Iterator::Flex::Factory->to_iterator( $_, { ( +EXHAUSTION ) => +RETURN } ) } @depends;
-    my $value;
-    $value = $current
-      if $thaw;
+      = map { Iterator::Flex::Factory->to_iterator( $_, { ( +EXHAUSTION ) => RETURN } ) } @depends;
+
+    # -- not sure if this is just cargo-culted
+    # my $value;
+    # $value = $current
+    #   if $thaw;
 
     my $self;
     my $iterator_state;
@@ -90,11 +92,12 @@ sub construct ( $class, $state ) {
         ( +STATE ) => \$iterator_state,
 
         ( +NEXT ) => sub {
-            return $self->signal_exhaustion if $iterator_state == +IterState_EXHAUSTED;
+            return $self->signal_exhaustion if $iterator_state == IterState_EXHAUSTED;
 
             $current_iterator_index = 0
               if !defined $current_iterator_index;
 
+            ## no critic (CStyleForLoops)
             for ( ; $current_iterator_index < @iterators ; $current_iterator_index++ ) {
                 my $iter  = $iterators[$current_iterator_index];
                 my $value = $iter->();
@@ -116,7 +119,7 @@ sub construct ( $class, $state ) {
         },
 
         ( +CURRENT ) => sub {
-            return $self->signal_exhaustion if $iterator_state eq +IterState_EXHAUSTED;
+            return $self->signal_exhaustion if $iterator_state eq IterState_EXHAUSTED;
             return $current;
         },
 
@@ -189,7 +192,7 @@ Iterator::Flex::Cat - An iterator which concatenates a set of iterators
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 METHODS
 
