@@ -5,10 +5,10 @@ package Iterator::Flex::Role::Exhaustion::Throw;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Ref::Util;
-use Iterator::Flex::Utils qw( :default :RegistryKeys );
+use Iterator::Flex::Utils qw( :default REG_GENERAL REG_GP_EXHAUSTION );
 
 use Role::Tiny;
 use experimental 'signatures';
@@ -28,7 +28,7 @@ use namespace::clean;
 sub signal_exhaustion ( $self, @ ) {
     $self->set_exhausted;
 
-    my $exception = $REGISTRY{ refaddr $self }{ +GENERAL }{ +EXHAUSTION }[1];
+    my $exception = $REGISTRY{ refaddr $self }[REG_GENERAL][REG_GP_EXHAUSTION][1];
 
     $exception->() if Ref::Util::is_coderef( $exception );
 
@@ -61,7 +61,7 @@ Iterator::Flex::Role::Exhaustion::Throw - signal exhaustion by setting exhausted
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 METHODS
 
